@@ -23,9 +23,11 @@ function setup_openstack_clients {
     if [[ $SCENARIO == scenario_nfv ]]; then
         packages+=(python-tackerclient python-barbicanclient python-mistralclient)
     fi
-    virtualenv ~/openstackclient-venv
+    if [[ "debian" == $BASE_DISTRO ]]; then
+        sudo apt -y install python3-venv
+    fi
+    python3 -m venv ~/openstackclient-venv
     ~/openstackclient-venv/bin/pip install -U pip
-    ~/openstackclient-venv/bin/pip install -U setuptools
     ~/openstackclient-venv/bin/pip install -c $UPPER_CONSTRAINTS ${packages[@]}
 }
 
@@ -40,13 +42,13 @@ function prepare_images {
         GATE_IMAGES="bifrost"
     fi
 
-    if [[ $SCENARIO == "ceph" ]]; then
-        GATE_IMAGES+=",^ceph,^cinder"
+    if [[ $SCENARIO == "ceph-ansible" ]]; then
+        GATE_IMAGES+=",^cinder"
     fi
 
     if [[ $SCENARIO == "zun" ]]; then
         GATE_IMAGES+=",^zun,^kuryr,^etcd,^cinder,^iscsid"
-        if [[ $BASE_DISTRO != "centos" ]] || [[ $BASE_DISTRO_MAJOR_VERSION -eq 7 ]]; then
+        if [[ $BASE_DISTRO != "centos" ]]; then
             GATE_IMAGES+=",^tgtd"
         fi
     fi
@@ -65,42 +67,18 @@ function prepare_images {
         GATE_IMAGES+=",^swift"
     fi
 
+    if [[ $SCENARIO == "ovn" ]]; then
+        GATE_IMAGES+=",^ovn"
+    fi
+
     if [[ $SCENARIO == "mariadb" ]]; then
-        GATE_IMAGES="^cron,^haproxy,^keepalived,^kolla-toolbox,^mariadb"
+        GATE_IMAGES="^cron,^fluentd,^haproxy,^keepalived,^kolla-toolbox,^mariadb"
     fi
 
     if [[ $SCENARIO == "prometheus-efk" ]]; then
         GATE_IMAGES="^cron,^elasticsearch,^fluentd,^grafana,^haproxy,^keepalived,^kibana,^kolla-toolbox,^mariadb,^memcached,^prometheus,^rabbitmq"
     fi
 
-    # NOTE(yoctozepto): we cannot build and push at the same time on debian
-    # buster see https://github.com/docker/for-linux/issues/711.
-    PUSH="true"
-    if [[ "debian" == $BASE_DISTRO ]]; then
-        PUSH="false"
-    fi
-
-    sudo tee /etc/kolla/kolla-build.conf <<EOF
-[DEFAULT]
-namespace = lokolla
-base = ${BASE_DISTRO}
-install_type = ${INSTALL_TYPE}
-tag = ${TAG}
-profile = gate
-registry = 127.0.0.1:4000
-push = ${PUSH}
-logs_dir = /tmp/logs/build
-template_override = /etc/kolla/template_overrides.j2
-EOF
-
-    # TODO(mgoddard): Remove this if block when CentOS 7 is no longer
-    # supported.
-    if [[ $BASE_DISTRO == "centos" ]] && [[ $BASE_DISTRO_MAJOR_VERSION -eq 8 ]]; then
-        sudo tee -a /etc/kolla/kolla-build.conf <<EOF
-base_tag = 8
-EOF
-    fi
-
     sudo tee -a /etc/kolla/kolla-build.conf <<EOF
 [profiles]
 gate = ${GATE_IMAGES}
@@ -110,14 +88,10 @@ EOF
 
     sudo docker run -d -p 4000:5000 --restart=always -v /opt/kolla_registry/:/var/lib/registry --name registry registry:2
 
-    virtualenv ~/kolla-venv
+    python3 -m venv ~/kolla-venv
     . ~/kolla-venv/bin/activate
 
-    # Install newest setuptools to avoid issues on Python 2
-    pip install -U pip
-    pip install -U setuptools
-
-    pip install -c $UPPER_CONSTRAINTS "${KOLLA_SRC_DIR}"
+    pip install "${KOLLA_SRC_DIR}"
 
     sudo ~/kolla-venv/bin/kolla-build
 
