@@ -11,7 +11,7 @@ function test_smoke {
     openstack --debug compute service list
     openstack --debug network agent list
     openstack --debug orchestration service list
-    if [[ $SCENARIO == "ceph" ]] || [[ $SCENARIO == "zun" ]]; then
+    if [[ $SCENARIO == "ceph-ansible" ]] || [[ $SCENARIO == "zun" ]]; then
         openstack --debug volume service list
     fi
 }
@@ -28,7 +28,7 @@ function test_instance_boot {
     fi
     echo "SUCCESS: Server creation"
 
-    if [[ $SCENARIO == "ceph" ]] || [[ $SCENARIO == "zun" ]]; then
+    if [[ $SCENARIO == "ceph-ansible" ]] || [[ $SCENARIO == "zun" ]]; then
         echo "TESTING: Cinder volume attachment"
         openstack volume create --size 2 test_volume
         attempt=1
@@ -70,6 +70,33 @@ function test_instance_boot {
         echo "SUCCESS: Cinder volume attachment"
     fi
 
+    echo "TESTING: Floating ip allocation"
+    fip_addr=$(openstack floating ip create public1 -f value -c floating_ip_address)
+    openstack server add floating ip kolla_boot_test ${fip_addr}
+    echo "SUCCESS: Floating ip allocation"
+
+    echo "TESTING: PING&SSH to floating ip"
+    attempts=12
+    for i in $(seq 1 ${attempts}); do
+        if ping -c1 -W1 ${fip_addr} && ssh -v -o BatchMode=yes -o StrictHostKeyChecking=no cirros@${fip_addr} hostname; then
+            break
+        elif [[ $i -eq ${attempts} ]]; then
+            echo "Failed to access server via SSH after ${attempts} attempts"
+            echo "Console log:"
+            openstack console log show kolla_boot_test
+            return 1
+        else
+            echo "Cannot access server - retrying"
+        fi
+        sleep 10
+    done
+    echo "SUCCESS: PING&SSH to floating ip"
+
+    echo "TESTING: Floating ip deallocation"
+    openstack server remove floating ip kolla_boot_test ${fip_addr}
+    openstack floating ip delete ${fip_addr}
+    echo "SUCCESS: Floating ip deallocation"
+
     echo "TESTING: Server deletion"
     openstack server delete --wait kolla_boot_test
     echo "SUCCESS: Server deletion"
