@@ -24,6 +24,9 @@ import jinja2
 import yaml
 
 
+from kolla_ansible.put_address_in_context import put_address_in_context
+
+
 PROJECT_ROOT = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
 
 NEWLINE_EOF_INCLUDE_PATTERNS = ['*.j2', '*.yml', '*.py', '*.sh']
@@ -37,6 +40,19 @@ YAML_INCLUDE_PATTERNS = ['*.yml']
 YAML_EXCLUDE_PATTERNS = ['.tox', '.testrepository', '.git',
                          'defaults', 'templates', 'vars']
 
+KOLLA_NETWORKS = [
+    'api',
+    'storage',
+    'cluster',
+    'swift_storage',
+    'swift_replication',
+    'migration',
+    'tunnel',
+    'octavia_network',
+    'bifrost_network',
+    'dns',  # designate
+]
+
 logging.basicConfig()
 LOG = logging.getLogger(__name__)
 
@@ -78,6 +94,15 @@ def check_json_j2():
     def basename_filter(text):
         return text.split('\\')[-1]
 
+    def kolla_address_filter_mock(network_name, hostname=None):
+        # no validation is possible for the hostname
+
+        if network_name not in KOLLA_NETWORKS:
+            raise ValueError("{network_name} not in KOLLA_NETWORKS"
+                             .format(network_name=network_name))
+
+        return "127.0.0.1"
+
     # Mock ansible hostvars variable, which is a nested dict
     def hostvars():
         return collections.defaultdict(hostvars)
@@ -91,6 +116,9 @@ def check_json_j2():
             loader=jinja2.FileSystemLoader(root))
         env.filters['bool'] = bool_filter
         env.filters['basename'] = basename_filter
+        env.filters['kolla_address'] = kolla_address_filter_mock
+        env.filters['put_address_in_context'] = \
+            put_address_in_context
         template = env.get_template(filename)
         # Mock ansible variables.
         context = {
@@ -122,8 +150,7 @@ def check_docker_become():
                           for x in YAML_INCLUDE_PATTERNS])
     excludes = r'|'.join([fnmatch.translate(x)
                           for x in YAML_EXCLUDE_PATTERNS])
-    docker_modules = ('kolla_docker', 'kolla_ceph_keyring',
-                      'kolla_container_facts', 'kolla_toolbox')
+    docker_modules = ('kolla_docker', 'kolla_container_facts', 'kolla_toolbox')
     cmd_modules = ('command', 'shell')
     return_code = 0
     roles_path = os.path.join(PROJECT_ROOT, 'ansible', 'roles')
@@ -144,13 +171,19 @@ def check_docker_become():
                                       "task %s in %s",
                                       module, task['name'], fullpath)
                     for module in cmd_modules:
-                        if (module in task and
-                                task[module].startswith('docker') and
-                                not task.get('become')):
-                            return_code = 1
-                            LOG.error("Use of docker in %s module without "
-                                      "become in task %s in %s",
-                                      module, task['name'], fullpath)
+                        docker_without_become = False
+                        if (module in task and not task.get('become')):
+                            if (isinstance(task[module], str) and
+                                    (task[module]).startswith('docker')):
+                                docker_without_become = True
+                            if (isinstance(task[module], dict) and
+                                    task[module]['cmd'].startswith('docker')):
+                                docker_without_become = True
+                            if docker_without_become:
+                                return_code = 1
+                                LOG.error("Use of docker in %s module without "
+                                          "become in task %s in %s",
+                                          module, task['name'], fullpath)
 
     return return_code
 
@@ -163,5 +196,6 @@ def main():
     )
     return sum([check() for check in checks])
 
+
 if __name__ == "__main__":
     sys.exit(main())
